"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fetchUtil_1 = require("../util/fetchUtil");
const monacoFacade_1 = require("./monacoFacade");
/**
 * get all @types dependencies from package.json and query https://unpkg.com/@types/... to download its index.d.ts
 * then instruct monaco to add them
 *
 * TODO: there could be dependencies that dont need @type we should query all by package.json and see its typing property
 */
function installTypes(project, projectNature) {
    return new Promise((resolve, reject) => {
        let pj;
        if (!project || !project.files || !(pj = project.files.find(f => f.fileName === 'package.json'))) {
            return reject('No package.json');
        }
        const packageJSON = JSON.parse(pj.content);
        let deps = [];
        Object.keys(packageJSON.dependencies || {}).filter(k => k.startsWith('@types'))
            .forEach(d => deps.push({ name: d, version: packageJSON.dependencies[d] }));
        Object.keys(packageJSON.devDependencies || {}).filter(k => k.startsWith('@types'))
            .forEach(d => deps.push({ name: d, version: packageJSON.devDependencies[d] }));
        deps = heuristicSort(deps);
        Promise.all(deps.map(d => fetchUtil_1.fetchFileText(`https://unpkg.com/${d.name}@${d.version}/index.d.ts`)))
            .then(depsResponses => {
            depsResponses.forEach((text, i) => {
                const d = deps[i];
                const fileName = `node_modules/@types${d.name.substring('@types'.length, d.name.length)}/index.d.ts`;
                monacoFacade_1.getMonaco().languages.typescript.typescriptDefaults.addExtraLib(text, fileName);
            });
            resolve(projectNature);
        }).catch(reject);
    });
}
exports.installTypes = installTypes;
function heuristicSort(deps) {
    const n = deps.findIndex(d => d.name.startsWith('@types/node'));
    if (n != -1) {
        const aux = deps[0];
        deps[0] = deps[n];
        deps[n] = aux;
    }
    return deps;
}
function monacoAddExtraLibrary(lib, content) {
    let libResource;
    try {
        const fileName = `node_modules/typescript/lib/${lib}`;
        const url = `https://unpkg.com/typescript@2.9.2/lib/${lib}`;
        console.log(`addExtraLib url: ${url} . Filename: ${fileName}. libs value: ${lib}`);
        libResource = { fileName, url, content };
        monacoFacade_1.getMonaco().languages.typescript.typescriptDefaults.addExtraLib(content, fileName);
    }
    catch (ex) {
        libResource.error = ex;
    }
    return libResource;
}
exports.monacoAddExtraLibrary = monacoAddExtraLibrary;
//# sourceMappingURL=installTypes.js.map