"use strict";
/**
 * this file is responsible of inspecting tsconfig.json and package.json if any and to identify the nature of the
 * project and load tsconfig.lib incase of TS or just lib.d.ts in case of JS (See installTypes.ts and comes later
 * to add more types - this is just lib.d.ts)
 */
Object.defineProperty(exports, "__esModule", { value: true });
const monacoFacade_1 = require("./monacoFacade");
const tsUtil_1 = require("../util/tsUtil");
const fetchUtil_1 = require("../util/fetchUtil");
const installTypes_1 = require("./installTypes");
/**
 * set compiled options in monaco defaults from tsconfig.json file in given project
 * also tsconfig lib[] are loaded from https://unpkg.com/typescript@2.9.2/lib/ and added with addExtraLib
 * TODO: wait until getTs() is true
 * @param project
 */
function installTsConfig(project) {
    return new Promise(resolve => {
        function loadCompilerOptions(options) {
            nature.tsConfig.compilerOptions = options;
            const libs = options.lib || [];
            try {
                monacoFacade_1.getMonaco().languages.typescript.typescriptDefaults.setCompilerOptions(options);
                // heads up . getMonaco().languages.javascript is not defined in monaco-editor/api.d.ts
                const languagesAsAny = monacoFacade_1.getMonaco().languages;
                if (languagesAsAny.javascript && languagesAsAny.javascript.javascriptDefaults && languagesAsAny.javascript.javascriptDefaults.setCompilerOptions) {
                    languagesAsAny.javascript.javascriptDefaults.setCompilerOptions(options);
                }
            }
            catch (ex) {
                nature.tsConfig.monacoSetCompilerOptionsError = ex;
            }
            Promise.all(libs.map(l => fetchUtil_1.fetchFileText(`https://unpkg.com/typescript@2.9.2/lib/${l}`)))
                .then(depsResponses => {
                depsResponses.forEach((content, i) => {
                    let libResource = installTypes_1.monacoAddExtraLibrary(libs[i], content);
                    nature.tsConfig.libs.push(libResource);
                });
                resolve(nature);
            }).catch(ex => {
                nature.tsConfig.libsLoadingError = ex;
                resolve(nature);
            });
        }
        const nature = {
            type: 'unknown',
            extraLibAdded: [],
            tsConfig: {
                libs: []
            },
            packageJson: {
                libs: []
            }
        };
        const tsconfig = project.files.find(f => f.fileName === 'tsconfig.json');
        let options;
        if (tsconfig && tsUtil_1.getTs()) {
            try {
                options = tsUtil_1.buildCompilerOptions(tsconfig.content);
            }
            catch (error) {
                nature.tsConfig.errorLoadingTsConfigJson = error;
            }
        }
        if (options) {
            // assume is a TS project. Now proceed to load libs
            nature.type = 'typescript';
            loadCompilerOptions(options);
            resolve(nature);
        }
        else {
            // assume is not a TS project. Try to load a package.json file to see if it at least is JS project
            const packageJson = project.files.find(f => f.fileName === 'package.json');
            if (!packageJson) {
                nature.packageJson.exists = false;
                return resolve(nature);
            }
            let pj;
            try {
                pj = JSON.parse(packageJson.content);
            }
            catch (ex) {
                nature.packageJson.errorLoadingPackageJson = ex;
                return resolve(nature);
            }
            // assume is a JS project. we load a default tsconfig with all its libraries just as with typescript nature
            nature.type = 'javascript';
            loadCompilerOptions(tsUtil_1.getTs().getDefaultCompilerOptions());
            resolve(nature);
        }
    });
}
exports.installTsConfig = installTsConfig;
//# sourceMappingURL=tsConfig.js.map