import * as monaco from 'monaco-editor';
import * as ts from "typescript";
export interface ITypeScriptWorker {
    getCompilationSettings(): ts.CompilerOptions;
    getScriptFileNames(): Promise<string[]>;
    getScriptVersion(fileName: string): string;
    getScriptSnapshot(fileName: string): ts.IScriptSnapshot;
    getScriptKind(fileName: string): ts.ScriptKind;
    getCurrentDirectory(): string;
    getDefaultLibFileName(options: ts.CompilerOptions): string;
    isDefaultLibFileName(fileName: string): boolean;
    getSyntacticDiagnostics(fileName: string): Promise<ts.Diagnostic[]>;
    getSemanticDiagnostics(fileName: string): Promise<ts.Diagnostic[]>;
    getCompilerOptionsDiagnostics(fileName: string): Promise<ts.Diagnostic[]>;
    getCompletionsAtPosition(fileName: string, position: number): Promise<ts.CompletionInfo>;
    getCompletionEntryDetails(fileName: string, position: number, entry: string): Promise<ts.CompletionEntryDetails>;
    getSignatureHelpItems(fileName: string, position: number): Promise<ts.SignatureHelpItems>;
    getQuickInfoAtPosition(fileName: string, position: number): Promise<ts.QuickInfo>;
    getOccurrencesAtPosition(fileName: string, position: number): Promise<ts.ReferenceEntry[]>;
    getDefinitionAtPosition(fileName: string, position: number): Promise<ts.DefinitionInfo[]>;
    getReferencesAtPosition(fileName: string, position: number): Promise<ts.ReferenceEntry[]>;
    getNavigationBarItems(fileName: string): Promise<ts.NavigationBarItem[]>;
    getFormattingEditsForDocument(fileName: string, options: ts.FormatCodeOptions): Promise<ts.TextChange[]>;
    getFormattingEditsForRange(fileName: string, start: number, end: number, options: ts.FormatCodeOptions): Promise<ts.TextChange[]>;
    getFormattingEditsAfterKeystroke(fileName: string, postion: number, ch: string, options: ts.FormatCodeOptions): Promise<ts.TextChange[]>;
    getEmitOutput(fileName: string): Promise<ts.EmitOutput>;
}
export declare function getTsWorker(uri: monaco.Uri): Promise<ITypeScriptWorker>;
export declare function getDefinitionAtPosition(fileName: monaco.Uri, position: number): Promise<ts.DefinitionInfo[]>;
export declare function getNavigationBarItems(fileName: monaco.Uri): Promise<ts.NavigationBarItem[]>;
export declare function getSyntacticDiagnostics(fileName: monaco.Uri): Promise<ts.Diagnostic[]>;
export declare function getSemanticDiagnostics(fileName: monaco.Uri): Promise<ts.Diagnostic[]>;
export declare function getCompilerOptionsDiagnostics(fileName: monaco.Uri): Promise<ts.Diagnostic[]>;
export declare function getScriptFileNames(): Promise<string[]>;
export declare function getMonacoDefinitionAtPosition(model: monaco.editor.IModel, position: monaco.IPosition): Promise<monaco.languages.Location[]>;
