"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const monacoFacade_1 = require("./monacoFacade");
function getTsWorker(uri) {
    return new Promise(resolve => {
        monacoFacade_1.getMonaco().languages.typescript.getTypeScriptWorker().then(_worker => {
            _worker(uri).then(resolve);
        });
    });
}
exports.getTsWorker = getTsWorker;
function getDefinitionAtPosition(fileName, position) {
    return getTsWorker(fileName)
        .then(worker => {
        return worker.getDefinitionAtPosition(fileName.toString(), position);
    });
}
exports.getDefinitionAtPosition = getDefinitionAtPosition;
function getNavigationBarItems(fileName) {
    return getTsWorker(fileName)
        .then(worker => {
        return worker.getNavigationBarItems(fileName.toString());
    });
}
exports.getNavigationBarItems = getNavigationBarItems;
function getSyntacticDiagnostics(fileName) {
    return getTsWorker(fileName)
        .then(worker => {
        return worker.getSyntacticDiagnostics(fileName.toString());
    });
}
exports.getSyntacticDiagnostics = getSyntacticDiagnostics;
function getSemanticDiagnostics(fileName) {
    return getTsWorker(fileName)
        .then(worker => {
        return worker.getSemanticDiagnostics(fileName.toString());
    });
}
exports.getSemanticDiagnostics = getSemanticDiagnostics;
function getCompilerOptionsDiagnostics(fileName) {
    return getTsWorker(fileName)
        .then(worker => {
        return worker.getCompilerOptionsDiagnostics(fileName.toString());
    });
}
exports.getCompilerOptionsDiagnostics = getCompilerOptionsDiagnostics;
getCompilerOptionsDiagnostics;
function getScriptFileNames() {
    return getTsWorker(monacoFacade_1.getMonaco().editor.getModels().find(m => !m.isDisposed()).uri)
        .then(worker => {
        return worker.getScriptFileNames();
    });
}
exports.getScriptFileNames = getScriptFileNames;
function getMonacoDefinitionAtPosition(model, position) {
    return new Promise((resolve, reject) => {
        getDefinitionAtPosition(model.uri, model.getOffsetAt(position)).then(defs => {
            if (defs) {
                const locations = defs.map(def => {
                    const uri = monacoFacade_1.getMonaco().Uri.parse(def.fileName);
                    const targetModel = monacoFacade_1.getMonaco().editor.getModel(uri);
                    if (!targetModel) {
                        return undefined;
                    }
                    const range = monacoFacade_1.getMonaco().Range.fromPositions(targetModel.getPositionAt(def.textSpan.start), targetModel.getPositionAt(def.textSpan.start + def.textSpan.length));
                    return {
                        uri,
                        range
                    };
                }).filter(l => !!l);
                resolve(locations);
            }
            resolve([]);
        }).catch(reject);
    });
}
exports.getMonacoDefinitionAtPosition = getMonacoDefinitionAtPosition;
//# sourceMappingURL=tsWorker.js.map