import monaco from 'monaco-editor';
import { AbstractProject } from '../types';
import { ActionManager } from './actionManager';
import { ProjectNature } from './tsConfig';
export declare abstract class Workspace {
    projectNature: ProjectNature;
    actionManager: ActionManager;
    /**
     * The very first call, will make sure monaco editor, typescript and other necessary resources
     * are loaded . Also do initial setup (register some internal listeners / initial configuration).
     * Will start notifying user events, particularly user navigating to other files so users can
     * implement the experience (See onNavigateToOtherFile).
     * @returns a promise resolved when everything is ready for the user to start rendering their app
     * and working with monaco
     */
    setup(): Promise<void>;
    /**
     * This method will be called when the user navigates a different file using ctrl+click on
     * references. The default implementation open the next sourcefile in the same editor. User can
     * override it to support other experience such as open a new editor in a new tab.
     */
    protected willNavigateToOtherFile(oldEditor: monaco.editor.ICodeEditor, model: monaco.editor.IModel, def: monaco.languages.Location): void;
    projectChanged(project: AbstractProject): Promise<ProjectNature>;
    /**
     * The framework could notify when the current selected file changes - this could sometimes be
     * managed by the framework, for example in the default implementation of willNavigateToOtherFile
     */
    abstract selectedFileChanged(fileName: string): void;
}
