"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
const util_1 = require("../util");
const actionManager_1 = require("./actionManager");
const installTypes_1 = require("./installTypes");
const monacoFacade_1 = require("./monacoFacade");
const register_1 = require("./register");
const tsConfig_1 = require("./tsConfig");
class Workspace {
    /**
     * The very first call, will make sure monaco editor, typescript and other necessary resources
     * are loaded . Also do initial setup (register some internal listeners / initial configuration).
     * Will start notifying user events, particularly user navigating to other files so users can
     * implement the experience (See onNavigateToOtherFile).
     * @returns a promise resolved when everything is ready for the user to start rendering their app
     * and working with monaco
     */
    setup() {
        return monacoFacade_1.monacoLoaded()
            .then(() => {
            // now we load a .ts monaco model so we trigger ts languageService loading so we dont wait 
            // forever for the following promise:
            register_1.getMonacoModelFor({ fileName: '_blank.ts', content: '' });
            return util_1.tsLoaded();
        })
            .then(() => {
            __1.getMonaco().languages.typescript.typescriptDefaults.setEagerModelSync(true);
            __1.monacoEditorEmitter.on('editorRegistered', (editor) => {
                __1.install(editor, (editor, model, def) => {
                    this.willNavigateToOtherFile(editor, model, def);
                });
            });
            this.actionManager = actionManager_1.getActionManager(this);
        });
    }
    /**
     * This method will be called when the user navigates a different file using ctrl+click on
     * references. The default implementation open the next sourcefile in the same editor. User can
     * override it to support other experience such as open a new editor in a new tab.
     */
    willNavigateToOtherFile(oldEditor, model, def) {
        // heads up - we can't perform the selection and revealPosition in oldEditor since 
        __1.monacoEditorEmitter.once('editorRegistered', editor => {
            editor.revealPositionInCenter({ column: def.range.startColumn, lineNumber: def.range.startLineNumber });
            editor.setSelection(def.range);
        });
        this.selectedFileChanged(register_1.uriToFileName(model.uri));
    }
    /*
     * User must notify the workspace that another project is loaded.
     */
    projectChanged(project) {
        register_1.resetMonacoModelsAndEditors();
        return tsConfig_1.installTsConfig(project)
            .then(projectNature => {
            this.projectNature = projectNature;
            register_1.createAllMonacoModelsFor(project);
            return installTypes_1.installTypes(project, this.projectNature);
        });
    }
}
exports.Workspace = Workspace;
//# sourceMappingURL=workspaceManager.js.map