"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const monacoFacade_1 = require("../monaco/monacoFacade");
const register_1 = require("../monaco/register");
/**
 * A React component ready to use, just give it the file, dimension and configuration as properties and it will render.
 */
class Editor extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.defaultMonacoOptions = {
            automaticLayout: true,
            lightbulb: { enabled: true }
        };
    }
    render() {
        this.containerId = this.props.id || ('_id_' + Date.now());
        return (react_1.default.createElement("div", { className: "editor", id: this.containerId, style: { width: this.props.width || '400px', height: this.props.height || '400px' } }));
    }
    componentDidUpdate() {
        this.installMonaco();
    }
    componentDidMount() {
        this.installMonaco();
    }
    installMonaco() {
        const model = register_1.getMonacoModelFor(this.props.file);
        const monacoOptions = Object.assign({}, this.defaultMonacoOptions, this.props.monacoEditorOptions || {}, { model });
        this.monacoEditor = monacoFacade_1.getMonaco().editor.create(document.getElementById(this.containerId), monacoOptions);
        register_1.registerEditor(this.monacoEditor);
    }
    uninstallMonaco() {
        if (this.monacoEditor) {
            this.monacoEditor.dispose();
        }
    }
    componentWillUnmount() {
        this.uninstallMonaco();
    }
    componentWillUpdate() {
        this.uninstallMonaco();
    }
    componentWillMount() {
        this.uninstallMonaco();
    }
}
exports.Editor = Editor;
/**
 * Example:
 *
 * ```
 * const editor = renderEditor({container: document.getElementById('my-awesome-editor2')})
 * editor.monacoEditor.onKeyUp()..
 * ```
 * a function to render the editor with given it the fie, dimension, container and configuration as properties and it
 * will render for those not confortable with react
 */
function renderEditor(options) {
    const editor = new Editor(options);
    react_dom_1.default.render([editor.render()], options.container);
    editor.installMonaco();
    return editor;
}
exports.renderEditor = renderEditor;
//# sourceMappingURL=Editor.js.map