"use strict";
// move tis as a separate library
Object.defineProperty(exports, "__esModule", { value: true });
function loadScript(opts) {
    return new Promise((resolve, reject) => {
        opts.container = opts.container || document.getElementsByTagName("head")[0];
        opts.callback = opts.callback || (arg => { });
        const script = document.createElement("script");
        const scriptAsAny = script;
        scriptAsAny.onload = scriptAsAny.onerror = scriptAsAny['onreadystatechange'] = function (...args) {
            if (scriptAsAny['readyState'] && !(/^c|loade/.test(scriptAsAny['readyState']))) {
                return;
            }
            resolve(args);
            opts.callback([]);
        };
        script.type = "text/javascript";
        if (opts.src) {
            script.src = opts.src;
            if (opts.crossorigin) {
                script.crossOrigin = "true";
                script.setAttribute('crossorigin', 'true');
            }
            if (opts.async) {
                script.async = true;
            }
            else {
                script.async = false;
            }
        }
        else if (opts.scriptBody) {
            script.innerHTML = opts.scriptBody;
        }
        else {
            reject(new Error('href or styleBody must be provided'));
            return;
        }
        opts.container.appendChild(script);
        if (!opts.src) {
            resolve([]);
            opts.callback([]);
        }
    });
}
exports.loadScript = loadScript;
function loadCSS(opts) {
    opts.container = opts.container || document.getElementsByTagName("head")[0];
    opts.callback = opts.callback || (args => { });
    if (opts.href) {
        const link = document.createElement('link');
        link.setAttribute('rel', 'stylesheet');
        link.setAttribute('type', 'text/css');
        link.setAttribute('href', opts.href);
        if (link.media) {
            link.media = 'media';
        }
        opts.container.appendChild(link);
        return Promise.resolve([]);
        //TODO: load events and resolve promise there
    }
    else if (opts.styleBody) {
        const style = document.createElement('style');
        style.setAttribute('type', 'text/css');
        style.innerHTML = opts.styleBody;
        opts.container.appendChild(style);
        return Promise.resolve([]);
    }
    else {
        return Promise.reject(new Error('href or styleBody must be provided'));
    }
}
exports.loadCSS = loadCSS;
async function loadSeries(opts) {
    const result = [];
    for (let i = 0; i < opts.length; i++) {
        const value = await load(opts[i]);
        result.push(value);
    }
    return result;
}
exports.loadSeries = loadSeries;
function load(opts) {
    if (opts.href || opts.styleBody) {
        return loadCSS(opts);
    }
    else {
        return loadScript(opts);
    }
}
exports.load = load;
function render(opts) {
    if (!Array.isArray(opts)) {
        opts = [opts];
    }
    return opts.map(opts => {
        if (opts.href || opts.styleBody) {
            return renderStyleLoadDefinition(opts);
        }
        else {
            return renderScriptLoadDefinition(opts);
        }
    }).join('\n\n');
}
exports.render = render;
function renderStyleLoadDefinition(opts) {
    if (opts.href) {
        return `<link rel="stylesheet" type="text/css" href="${opts.href}">`;
    }
    else if (opts.styleBody) {
        return `<style>
${opts.styleBody}
</style>`;
    }
    else {
        throw new Error('href or styleBody must be provided');
    }
}
exports.renderStyleLoadDefinition = renderStyleLoadDefinition;
function renderScriptLoadDefinition(opts) {
    if (opts.src) {
        return `<script type="text/javascript" src="${opts.src}" ${opts.crossorigin ? 'crossorigin' : ''} ${opts.async ? 'async' : ''}></script>`;
    }
    else if (opts.scriptBody) {
        return `<script type="text/javascript">
${opts.scriptBody}
</script>`;
        return '';
    }
    else {
        throw new Error('src or scriptBody must be provided');
    }
}
exports.renderScriptLoadDefinition = renderScriptLoadDefinition;
//# sourceMappingURL=loadScript.js.map