"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** a facade for obtaining ts implementation without loading typescript.js - like in a monaco-editor environment where the typescriptService.js is already loaded */
function getTs() {
    return window.ts;
}
exports.getTs = getTs;
exports.defaultFormatDiagnosticHost = {
    getCanonicalFileName(fileName) { return fileName; },
    getCurrentDirectory() { return ''; },
    getNewLine() { return '\n'; }
};
function buildCompilerOptions(compilerOptions) {
    let finalCompilerOptions;
    const ts = getTs();
    if (typeof compilerOptions === 'string') {
        const tsConfigJson = ts.parseConfigFileTextToJson('tsconfig.json', compilerOptions);
        if (tsConfigJson.error) {
            console.log('ts.parseConfigFileTextToJson ERROR: ' + tsConfigJson.error);
            throw tsConfigJson.error;
        }
        let { options, errors } = ts.convertCompilerOptionsFromJson(tsConfigJson.config.compilerOptions, '.');
        if (errors && errors.length) { //TODO. better errors
            throw errors;
        }
        finalCompilerOptions = options;
    }
    else {
        finalCompilerOptions = compilerOptions;
    }
    return finalCompilerOptions;
}
exports.buildCompilerOptions = buildCompilerOptions;
function tsLoaded() {
    const predicate = () => getTs() && getTs().createLanguageService;
    return new Promise(resolve => {
        if (predicate()) {
            resolve(getTs());
        }
        else {
            const timer = setInterval(() => {
                if (predicate()) {
                    clearInterval(timer);
                    resolve(getTs());
                }
            }, 100);
        }
    });
}
exports.tsLoaded = tsLoaded;
//# sourceMappingURL=tsUtil.js.map